==> haskell-persistent-template-2.5.2-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.2
id: persistent-template-2.5.2-LY7FDZHsqgZYkBG8JVwBO
key: persistent-template-2.5.2-LY7FDZHsqgZYkBG8JVwBO
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
abi: 034ec8e8459ca40298d4582deb50cd77
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/persistent-template-2.5.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/persistent-template-2.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/persistent-template-2.5.2
hs-libraries: HSpersistent-template-2.5.2-LY7FDZHsqgZYkBG8JVwBO
depends:
    aeson-1.1.2.0-2Tms2Hc2yE36x3yS5aZqW9
    aeson-compat-0.3.7-J1W3cj9RRES8gcGoS2sYkA base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1 ghc-prim-0.5.0.0
    http-api-data-0.3.7.1-6JL4GyjDoptconbqdu8s
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    monad-logger-0.3.24-Tw8ofbUiJ83GgIGlLSh9Z
    path-pieces-0.2.1-C48iBrmdGsmFVK7f4YbEhF
    persistent-2.6.1-IJIEOiZvQ7yAVPDrJvPITE
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.5.2-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.2
id: persistent-template-2.5.2-DGGdnOuoBhhBpLP87ReqGt
key: persistent-template-2.5.2-DGGdnOuoBhhBpLP87ReqGt
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
abi: e0bb6e3d9702e009791983475fa67e0f
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/persistent-template-2.5.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/persistent-template-2.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/persistent-template-2.5.2
hs-libraries: HSpersistent-template-2.5.2-DGGdnOuoBhhBpLP87ReqGt
depends:
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk
    aeson-compat-0.3.7-6r2isdi8sba2GQTe8lJbgH base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1 ghc-prim-0.5.0.0
    http-api-data-0.3.7.1-3zEe5ySvc6j6xRQh0wfGfT
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    monad-logger-0.3.24-3qXfgqb4hYc9kkpULw6T6e
    path-pieces-0.2.1-C48iBrmdGsmFVK7f4YbEhF
    persistent-2.6.1-BZtWNugaCvy4iJ6JpB9ZPy
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
